
========================  =========================  ==================================  =============  ==================================================================================================================================================
Key                       Type                       Options                             Default        Description                                                                                                                                       
========================  =========================  ==================================  =============  ==================================================================================================================================================
``guess_redshift``        ndarray, list, int, float  ..                                  0.0            Single or per-binned-spectrum redshift to use as the initial velocity guess.                                                                      
``guess_dispersion``      ndarray, list, int, float  ..                                  100.0          Single or per-binned-spectrum velocity dispersion to use as the initial guess.                                                                    
``emission_lines``        str                        ..                                  ``ELPMPL11``   Either a string identifying the database of emission lines to fit, or the direct path to the parameter file defining the database                 
``etpl_line_sigma_mode``  str                        ``default``, ``zero``, ``offset``   ``default``    Mode used to set the instrumental dispersion of the emission-line templates.  Mode options are explated by :func:`Sasuke.etpl_line_sigma_options`.
``etpl_line_sigma_min``   int, float                 ..                                  0.0            Impose a minimum emission-line sigma by offsetting the nominal trend, in quadrature, to have this minimum value.                                  
``deconstruct_bins``      str                        ``ignore``, ``nearest``, ``binid``  ``ignore``     Method to use for deconstructing binned spectra into individual spaxels for emission-line fitting.  See :func:`Sasuke.deconstruct_bin_options`.   
``template_library``      str, TemplateLibraryDef    ..                                  ``MASTARSSP``  Keyword identifier or definition object used to build the spectral template library used during the fit.                                          
``stellar_velocity``      ndarray, list, int, float  ..                                  ..             Single or per-binned-spectrum redshift of the stellar component                                                                                   
``stellar_dispersion``    ndarray, list, int, float  ..                                  ..             Single or per-binned-spectrum velocity dispersion of the stellar component                                                                        
``pixelmask``             SpectralPixelMask          ..                                  ..             Pixel mask to include during the fitting; see :func:`~mangadap.util.pixelmask.SpectralPixelMask`.                                                 
``reject_boxcar``         int                        ..                                  101            Size of the boxcar to use when rejecting fit outliers (must be odd).                                                                              
``velscale_ratio``        int                        ..                                  1              The **integer** ratio between the velocity scale of the pixel in the galaxy data to that of the template data.                                    
``degree``                int                        ..                                  -1             pPXF degree parameter setting the degree of the additive polynomials to use.                                                                      
``mdegree``               int                        ..                                  0              pPXF mdegree parameter setting the degree of the multiplicative polynomials to use.                                                               
``reddening``             int, float                 ..                                  ..             pPXF reddening parameter setting the initial :math:`E(B-V)` to fit, based on a Calzetti law.                                                      
========================  =========================  ==================================  =============  ==================================================================================================================================================

